 ![Flowers](./graphics/anarpy.png) 
 
 AnarPy - ANalysis And Replication in PYthon
==============================

AnarPy is a Python package to facilitate the simulation, analysis, and replication of several experiments using computational whole brain models.
For more details, installation instructions, documentation, tutorials, forums, videos and more, please visit: https://anarpy.readthedocs.io

This package is developed and maintained by the Valparaíso Neural Dynamics Laboratory at Universidad de Valparaíso (https://vandal-uv.github.io/)


Prerequisites
------------


Installation
------------
You can install this package with pip
```
pip install anarpy
```

Contributing
------------
Contribution is always welcomed! Please follow the contributing guidelines provided in the CONTRIBUTE file


Project Organization
------------

    ├── LICENSE
    ├── Makefile           <- Makefile with commands like `make data` or `make train`
    ├── README.md          <- The top-level README for developers using this project.
    │
    ├── docs               <- A default Sphinx project; see sphinx-doc.org for details
    │
    │
    ├── examples           <- Jupyter notebooks. Naming convention is a number (for ordering),
    │                         the creator's initials, and a short `-` delimited description, e.g.
    │                         `1.0-jqp-initial-data-exploration`.
    │
    ├── requirements.txt   <- The requirements file for reproducing the analysis environment, e.g.
    │                         generated with `pip freeze > requirements.txt`
    │
    ├── setup.py           <- makes project pip installable (pip install -e .) so src can be imported
    ├── src                <- Source code for use in this project.
    │   ├── __init__.py    <- Makes src a Python module
    │   │
    │   └── anarpy         <- Main package folder
    |       |
    │       ├── models     <- Different neuronal and neural mass models 
    |       |
    |       └── utils      <- Tools and utilities used in the lab
    │   
    │
    └── tox.ini            <- tox file with settings for running tox; see tox.readthedocs.io


--------


License
------------
The source code for the site is licensed under the MIT license, which you can find in the LICENSE file.

Citation
------------

Contact
------------
Code Mantainer: Javier Palma-Espinosa (javier.palma@cinv.cl)   
Principal Investigator: Patricio Orio (patricio.orio@cinv.cl)
